==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/github/workflows/WorkflowRunOptions.java <==
package io.github.cdklabs.projen.github.workflows;

/**
 * (experimental) Workflow run options.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.796Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.workflows.WorkflowRunOptions")
@software.amazon.jsii.Jsii.Proxy(WorkflowRunOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface WorkflowRunOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Which activity types to trigger on.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getTypes() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link WorkflowRunOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link WorkflowRunOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<WorkflowRunOptions> {
        java.util.List<java.lang.String> types;

        /**
         * Sets the value of {@link WorkflowRunOptions#getTypes}
         * @param types Which activity types to trigger on.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder types(java.util.List<java.lang.String> types) {
            this.types = types;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link WorkflowRunOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public WorkflowRunOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link WorkflowRunOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements WorkflowRunOptions {
        private final java.util.List<java.lang.String> types;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.types = software.amazon.jsii.Kernel.get(this, "types", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.types = builder.types;
        }

        @Override
        public final java.util.List<java.lang.String> getTypes() {
            return this.types;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getTypes() != null) {
                data.set("types", om.valueToTree(this.getTypes()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.workflows.WorkflowRunOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            WorkflowRunOptions.Jsii$Proxy that = (WorkflowRunOptions.Jsii$Proxy) o;

            return this.types != null ? this.types.equals(that.types) : that.types == null;
        }

        @Override
        public final int hashCode() {
            int result = this.types != null ? this.types.hashCode() : 0;
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/github/workflows/WorkflowRunOptions.java <==
package io.github.cdklabs.projen.github.workflows;

/**
 * (experimental) Workflow run options.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.464Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.workflows.WorkflowRunOptions")
@software.amazon.jsii.Jsii.Proxy(WorkflowRunOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface WorkflowRunOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Which branches or branch-ignore to limit the trigger to.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getBranches() {
        return null;
    }

    /**
     * (experimental) Which activity types to trigger on.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getTypes() {
        return null;
    }

    /**
     * (experimental) Which workflow to trigger on.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getWorkflows() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link WorkflowRunOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link WorkflowRunOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<WorkflowRunOptions> {
        java.util.List<java.lang.String> branches;
        java.util.List<java.lang.String> types;
        java.util.List<java.lang.String> workflows;

        /**
         * Sets the value of {@link WorkflowRunOptions#getBranches}
         * @param branches Which branches or branch-ignore to limit the trigger to.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder branches(java.util.List<java.lang.String> branches) {
            this.branches = branches;
            return this;
        }

        /**
         * Sets the value of {@link WorkflowRunOptions#getTypes}
         * @param types Which activity types to trigger on.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder types(java.util.List<java.lang.String> types) {
            this.types = types;
            return this;
        }

        /**
         * Sets the value of {@link WorkflowRunOptions#getWorkflows}
         * @param workflows Which workflow to trigger on.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder workflows(java.util.List<java.lang.String> workflows) {
            this.workflows = workflows;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link WorkflowRunOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public WorkflowRunOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link WorkflowRunOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements WorkflowRunOptions {
        private final java.util.List<java.lang.String> branches;
        private final java.util.List<java.lang.String> types;
        private final java.util.List<java.lang.String> workflows;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.branches = software.amazon.jsii.Kernel.get(this, "branches", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.types = software.amazon.jsii.Kernel.get(this, "types", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.workflows = software.amazon.jsii.Kernel.get(this, "workflows", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.branches = builder.branches;
            this.types = builder.types;
            this.workflows = builder.workflows;
        }

        @Override
        public final java.util.List<java.lang.String> getBranches() {
            return this.branches;
        }

        @Override
        public final java.util.List<java.lang.String> getTypes() {
            return this.types;
        }

        @Override
        public final java.util.List<java.lang.String> getWorkflows() {
            return this.workflows;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getBranches() != null) {
                data.set("branches", om.valueToTree(this.getBranches()));
            }
            if (this.getTypes() != null) {
                data.set("types", om.valueToTree(this.getTypes()));
            }
            if (this.getWorkflows() != null) {
                data.set("workflows", om.valueToTree(this.getWorkflows()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.workflows.WorkflowRunOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            WorkflowRunOptions.Jsii$Proxy that = (WorkflowRunOptions.Jsii$Proxy) o;

            if (this.branches != null ? !this.branches.equals(that.branches) : that.branches != null) return false;
            if (this.types != null ? !this.types.equals(that.types) : that.types != null) return false;
            return this.workflows != null ? this.workflows.equals(that.workflows) : that.workflows == null;
        }

        @Override
        public final int hashCode() {
            int result = this.branches != null ? this.branches.hashCode() : 0;
            result = 31 * result + (this.types != null ? this.types.hashCode() : 0);
            result = 31 * result + (this.workflows != null ? this.workflows.hashCode() : 0);
            return result;
        }
    }
}
